DetourEventName enum

Inheritance
Available extensions

Values

login → const DetourEventName
share → const DetourEventName
signUp → const DetourEventName
tutorialBegin → const DetourEventName
tutorialComplete → const DetourEventName
reEngage → const DetourEventName
invite → const DetourEventName
openedFromPushNotification → const DetourEventName
addPaymentInfo → const DetourEventName
addShippingInfo → const DetourEventName
addToCart → const DetourEventName
removeFromCart → const DetourEventName
refund → const DetourEventName
viewItem → const DetourEventName
beginCheckout → const DetourEventName
purchase → const DetourEventName
adImpression → const DetourEventName

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
rawValue String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DetourEventName>
A constant List of the values in this enum, in order of their declaration.