DetourResult class
Constructors
- DetourResult({required bool processed, DetourLink? link})
-
const
- DetourResult.fromMap(Map map)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- link → DetourLink?
-
final
- processed → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited