MethodChannelDetourFlutterPlugin class

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
linkStream Stream<DetourResult>
no setteroverride
methodChannel MethodChannel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

configure(DetourConfig config) Future<void>
override
logEvent(DetourEventName eventName, {Map<String, dynamic>? data}) Future<void>
override
logRetention(String eventName) Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
override
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited