DetourFlutterPluginPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • DetourFlutterPluginPlatform
Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
linkStream Stream<DetourResult>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

configure(DetourConfig config) Future<void>
logEvent(DetourEventName eventName, {Map<String, dynamic>? data}) Future<void>
logRetention(String eventName) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance DetourFlutterPluginPlatform
getter/setter pair